# Table of Contents

- [modeling-sap-cloud-solutions](<./modeling-sap-cloud-solutions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling SAP Cloud Solutions](<./Modeling-SAP-Cloud-Solutions.md>)
  - [SAP Cloud Solutions Modeling Perspectives](<./Modeling-SAP-Cloud-Solutions/SAP-Cloud-Solutions-Modeling-Perspectives.md>)
  - [SAP Cloud Solutions Modeling Best Practices and Guidelines](<./Modeling-SAP-Cloud-Solutions/SAP-Cloud-Solutions-Modeling-Best-Practices-and-Guidelines.md>)
  - [Handling Multiple Instances of SAP Cloud Solutions](<./Modeling-SAP-Cloud-Solutions/Handling-Multiple-Instances-of-SAP-Cloud-Solutions.md>)
  - [Modeling SAP Systems](<./Modeling-SAP-Cloud-Solutions/Modeling-SAP-Systems.md>)
  - [Modeling Instance Strategy With System Fact Sheets](<./Modeling-SAP-Cloud-Solutions/Modeling-Instance-Strategy-With-System-Fact-Sheets.md>)
